import { SelectionSetNode, FieldNode, FragmentSpreadNode, InlineFragmentNode, GraphQLNamedType, GraphQLSchema, GraphQLInterfaceType } from 'graphql';
import { ScalarsMap, ConvertNameFn, LoadedFragment } from './types';
import { GraphQLObjectType, GraphQLNonNull, GraphQLList } from 'graphql';
import { BaseVisitorConvertOptions } from './base-visitor';
export declare type PrimitiveField = string;
export declare type PrimitiveAliasedFields = {
    alias: string;
    fieldName: string;
};
export declare type LinkField = {
    alias: string;
    name: string;
    type: string;
    selectionSet: string;
};
export declare type FragmentsMap = {
    [onType: string]: string[];
};
export declare class SelectionSetToObject {
    protected _scalars: ScalarsMap;
    protected _schema: GraphQLSchema;
    protected _convertName: ConvertNameFn<BaseVisitorConvertOptions>;
    protected _addTypename: boolean;
    protected _preResolveTypes: boolean;
    protected _nonOptionalTypename: boolean;
    protected _loadedFragments: LoadedFragment[];
    protected _namespacedImportName: string | null;
    protected _parentSchemaType?: GraphQLNamedType;
    protected _selectionSet?: SelectionSetNode;
    protected _primitiveFields: PrimitiveField[];
    protected _primitiveAliasedFields: PrimitiveAliasedFields[];
    protected _linksFields: LinkField[];
    protected _fragments: FragmentsMap;
    protected _queriedForTypename: boolean;
    constructor(_scalars: ScalarsMap, _schema: GraphQLSchema, _convertName: ConvertNameFn<BaseVisitorConvertOptions>, _addTypename: boolean, _preResolveTypes: boolean, _nonOptionalTypename: boolean, _loadedFragments: LoadedFragment[], _namespacedImportName: string | null, _parentSchemaType?: GraphQLNamedType, _selectionSet?: SelectionSetNode);
    createNext(parentSchemaType: GraphQLNamedType, selectionSet: SelectionSetNode): SelectionSetToObject;
    protected wrapTypeWithModifiers(baseType: string, type: GraphQLObjectType | GraphQLNonNull<GraphQLObjectType> | GraphQLList<GraphQLObjectType>): string;
    _collectField(field: FieldNode): void;
    _collectFragmentSpread(node: FragmentSpreadNode): void;
    _collectInlineFragment(node: InlineFragmentNode): void;
    readonly string: string;
    protected buildFieldsWithoutPick(): string;
    protected buildAliasedPrimitiveFieldsWithoutPick(schemaType: GraphQLObjectType | GraphQLInterfaceType, fields: PrimitiveAliasedFields[]): {
        name: string;
        type: string;
    }[];
    protected buildLinkFieldsWithoutPick(fields: LinkField[]): {
        name: string;
        type: string;
    }[];
    protected buildPrimitiveFieldsWithoutPick(schemaType: GraphQLObjectType | GraphQLInterfaceType, fields: PrimitiveField[]): {
        name: string;
        type: string;
    }[];
    protected buildFieldsWithPick(): string;
    protected mergeAllFields(fieldsSet: Array<string | null>): string;
    protected getImplementingTypes(node: GraphQLInterfaceType): string[];
    protected buildTypeNameField(): {
        name: string;
        type: string;
    };
    protected buildPrimitiveFields(parentName: string, fields: PrimitiveField[]): string | null;
    protected buildAliasedPrimitiveFields(parentName: string, fields: PrimitiveAliasedFields[]): string | null;
    protected formatNamedField(name: string): string;
    protected buildLinkFields(fields: LinkField[]): string | null;
    protected buildFragments(fragments: FragmentsMap): string | null;
    protected _handleFragmentsForObjectType(fragments: FragmentsMap): string | null;
    protected _handleFragmentsForUnionAndInterface(fragments: FragmentsMap): string | null;
}
